Installation
============

Create a virtual environment with Python 3.7 or greater and simply run:

.. code-block:: console

	pip install airfrans
	
It will, in addition, install the following libraries: `NumPy <https://numpy.org/>`_, `PyVista <https://docs.pyvista.org/>`_ and, `tqdm <https://tqdm.github.io/>`_.
